@@ -1,3 +1,3 @@
 from .build_traj import TrajBuilder
-from .interpolator import Interpolator, WrappedInterp1d
+from .interpolator import Interpolator
 from .utils import *
\ No newline at end of file
